@@ -11,7 +11,7 @@ from tqdm import *
 from f61d.setu import setu,getDesktop
 
 
-VERSION = (0,5,5)
+VERSION = (0,5,6)
 VERSION = '.'.join(map(str, VERSION))
 
 
@@ -22,19 +22,21 @@ print(colored("Welcome to F61D. Use Help() for help.",'green'))
 help_cont = {}
 help_cont[0] = 'Help     : See this help page.\n\t\t  '+colored('Help(0)','cyan')+colored(' for all functions.','green')
 help_cont[1] = 'fuckStar : One Button to fuck Satellite'
-help_cont[9] = 'lifeGame : Play the Life Game'
+help_cont[2] = 'timeit   : Take a time for your function.\n\t\t  Just add a '+colored('@timeit','cyan')+colored(' before you define the function','green')
 help_cont[3] = 'paint    : Draw a Bing Dwen Dwen'
 help_cont[4] = 'b64tofile: Decode base64 to a file'
 help_cont[5] = 'prove    : Prove your self. Only support:\n\t\t  sha256(XXXX + abcdef) = aaabbb...'
 help_cont[6] = 'Nim      : An interesting turtle game.'
 help_cont[7] = 'getLogo  : Print the "F61D" LOGO.'
 help_cont[8] = 'yinyang  : Draw the TaiJi.'
-help_cont[2] = 'timeit   : Take a time for your function.\n\t\t  Just add a '+colored('@timeit','cyan')+colored(' before you define the function','green')
+help_cont[9] = 'lifeGame : Play the Life Game'
 help_cont[10] = 'Polynomial: from f61d.Polynomial2 import *'
 help_cont[11] = 'gmgj    : Common Modulus Attack in RSA'
 help_cont[12] = 'crt     : Chinese Remainder Theory'
-help_cont[12] = 'mtank   : 幻影坦克 Mirage tank maker'
-help_cont[13] = 'setu    : get a setu (or save it)'
+help_cont[13] = 'mtank   : 幻影坦克 Mirage tank maker'
+help_cont[14] = 'setu    : get a setu with your xp'
+help_cont[15] = 'fastsetu: get a random setu'
+
 
 
 def formatNumber(x):
